{% extends "base.html" %} {% block main %}

## Privacy

This webpage respects your privacy and collects as little information as possible while still providing a positive user experience. By using the application, you agree to the following.

### Data Collection

This application records standard server access logs for security and stability reasons, including to prevent abuse. This is a common practice employed by many websites necessary for maintaing application function. This information includes:

- IP addresses which describe from which location and internet connection the application is accessed.
- User agent strings which provide basic information about the device and software ("browser") used to access the site.
- The requested URLs which are unique identifiers for data and other resources requested from our servers.

These logs are maintained for security reasons and to ensure strong application performance but are anonymized within 7 days of collection. These anonymized statistics are maintained indefinently as aggregated information for us to understand usage patterns in order to improve the service and maintain its performance. The anonymized data may also include error or bug reports. That said, and no other presonal identifying information is collected including email address, phone number, race, ethnicity, age, etc. Furthermore, please note that:

- Personally identifying information is never shared or sold.
- Anonymized data do not include specific IP addresses.
- IP address is not retained past 7 days except for security / abuse prevention purposes if potential unusual behavior is deteced like in the case of a large number of requests.
- No information we collect is used for advertising.
- Though we do not ask users their age to respect their privacy, this webpage is intended for those 18 years and older.

### Data Storage

We save very limited data to your device and that data is not used to track you.

- Cookies are small text files saved to your computer to maintain data such as preferences between website sessions. This application uses essential cookies to support the core function of the application to, for example, prevent showing explanatory text multiple times and improve user experience. These cookies are required by the application to function.
- There are no non-essential cookies for this application and cookies are not used for tracking, advertising, or analytics.
- Some browsers may save temporary copies of our data and code for performance reasons through a process called "caching" which can be controlled through your browser settings. This application may use "cache-busters" to inform your browser when new versions of application resources are available.
- Local storage is used, for example, to save the application on your computer to support weak internet connections or offline usage. This includes the local storage of the Progressive Web Application if enabled and supported. Other use of local storage is optional in specific application features like in the online editor.

By using this application, you agree to the transfer of standard server access logs and anonymized statistics as described above to be transferred to data centers based within the United States of America.

### Security and Access

We take security seriously. Communication between your device and our servers is encrypted with secure socket layer SSL. Access to non-anonymized logs and the configuration / code for the application is limited to the current maintainers of the project, automated systems we've constructed for running the application, and our subprocessors. Note that anonymized data may be shared with project partners for the purposes of tracking project success and impact.

### Subprocessors

See DreamHost CDPA for more information about our web host / subprocessor.

### External sites

Note that external sites linked from this application maintain their own privacy policies, terms of service, and licensing. This website is not responsible for any external content. We define external content to include any content at any domain other than sketchingpy.org.

### Updates

This statement's content was last updated on 2023-12-26. Updates to this policy will be posted to this page. For questions and requests please email hello@sketchingpy.org.
{% endblock %}